-- Retrieves all ObserveIT Database version insatlled on the system
-- All applicaiotn Servers
-- Count of the Agents installed with OS type and AgentType
-- Applicaiotn Servers URL with number of Endpoints connected
-- Version 2.4

USE ObserveIT
GO
SET NOCOUNT ON
IF OBJECT_ID('tempdb..#OIT_DBs') IS NOT NULL DROP TABLE #OIT_DBs
IF OBJECT_ID('tempdb..#OIT_Versions') IS NOT NULL DROP TABLE #OIT_Versions
IF OBJECT_ID('tempdb..#OIT_Agents') IS NOT NULL DROP TABLE #OIT_Agents
IF OBJECT_ID('tempdb..#OIT_UnInstAgents') IS NOT NULL DROP TABLE #OIT_UnInstAgents
SELECT SERVERPROPERTY('edition') AS 'SQL Edition',@@VERSION AS 'SQLServerVersion                                                             '
GO
DECLARE @WC INT = (SELECT COUNT(1) FROM [ObserveIT].[dbo].[WebConsoles])
DECLARE @APP INT = (SELECT COUNT(1) FROM [ObserveIT].[dbo].[ApplicationServers])
DECLARE @AIO VARCHAR = 0
IF ((@WC = 1) AND (@APP = 1))
BEGIN
	IF ((SELECT MachineName FROM [ObserveIT].[dbo].[WebConsoles]) = (SELECT ServerName FROM [ObserveIT].[dbo].[ApplicationServers]))
	BEGIN
		SET @AIO = 1
	END
END
-- Check if DB is Partitioned
DECLARE @DBPartitioned INT=0
DECLARE @DBP1 INT=0
DECLARE @DBP2 INT=0
SELECT @DBP1 = count(1) FROM sys.partition_functions WHERE name IN ('PF_Day','PF_Day_DayTime')
SELECT @DBP2 = count(1) FROM sys.partition_schemes WHERE name IN ('PS_Day','PS_Day_DayTime')
IF (SUM(@DBP1+@DBP2) = 4)
BEGIN
	SET @DBPartitioned=1
END
--
SELECT CASE dc.DatabaseConfigurationValue
			WHEN 'false' THEN 'Enterprise Edition' 
			WHEN 'true' THEN 'No Label Edition' 
		END as 'ObserveIT Edition', CASE @AIO WHEN 0 THEN 'false' WHEN 1 THEN 'true' END as 'AIO',
		CASE @DBPartitioned WHEN 0 THEN 'False. Can not upgrade to 7.13 or above' WHEN 1 THEN 'True' END as 'Partitioned'
FROM DatabaseConfiguration dc 
WHERE dc.DatabaseConfigurationKey = 'IsNL'
GO
DECLARE @OIT_DbName NVARCHAR(256),
        @RowID INT,
        @Rows INT,
        @SqlCmd NVARCHAR(MAX)
CREATE TABLE #OIT_Versions
(
      DbName        NVARCHAR(256),
      ServerVersion NVARCHAR(20),
	  OldestSession	DATE,
	  NewestSession	DATE
)
SELECT ROW_NUMBER() OVER (ORDER BY DbName) AS RowID,DbName
INTO  #OIT_DBs
FROM  dbo.Archive_ArchiveDatabaseConfiguration
WHERE DbName IN (SELECT name COLLATE DATABASE_DEFAULT FROM sys.databases)
ORDER BY DbName
SET @Rows = @@ROWCOUNT
SET @RowID = 1
WHILE (@RowID <= @Rows)
BEGIN
      SELECT      @OIT_DbName = DbName 
      FROM        #OIT_DBs
      WHERE       RowID = @RowID
	 -- DECLARE @MinSess DATETIME
	 -- DECLARE @MaxSess DATETIME
      SELECT    @SqlCmd = 
                              'INSERT INTO #OIT_Versions
                              SELECT   TOP 1 ''' + @OIT_DbName + ''' AS DbName,
										s.ServerVersion, 
										(SELECT min(se1.SessionDate) FROM ' + @OIT_DbName + '.dbo.Session se1),
										(SELECT max(se2.SessionDate) FROM ' + @OIT_DbName + '.dbo.Session se2)
                              FROM     ' + @OIT_DbName + '.dbo.ServerVersions s'
      --PRINT(@SqlCmd)
      EXEC (@SqlCmd)
      SET @RowID = @RowID + 1
END
INSERT INTO #OIT_Versions
SELECT      TOP 1 'ObserveIT' AS DbName,ServerVersion, (SELECT min(SessionDate) FROM dbo.Session),(SELECT max(SessionDate) FROM dbo.Session) FROM  dbo.ServerVersions
if DB_ID('ObserveIT_Archive_Template') IS NOT NULL
BEGIN
      INSERT INTO #OIT_Versions
      SELECT      TOP 1 'ObserveIT_Archive_Template' AS DbName,ServerVersion, NULL,NULL FROM  ObserveIT_Archive_Template.dbo.ServerVersions
END
if DB_ID('ObserveIT_Analytics') IS NOT NULL
BEGIN
      INSERT INTO #OIT_Versions
      SELECT      TOP 1 'ObserveIT_Analytics' AS DbName,ServerVersion,NULL,NULL FROM  ObserveIT_Analytics.dbo.ServerVersions
END
SELECT * FROM #OIT_Versions ORDER BY DbName
GO
SELECT distinct(Version) AS  'WebConsole-Version', COUNT(1) AS 'Cnt'
FROM [ObserveIT].[dbo].[WebConsoles] 
GROUP BY Version
GO 
SELECT distinct(Version) AS 'Application-Servers-Version',COUNT(1) AS 'Cnt' 
FROM [ObserveIT].[dbo].[ApplicationServers] 
WHERE UpdatedDate > GETDATE()-3
GROUP BY Version
GO 
SELECT CASE StorageTypeId 
		WHEN 1 THEN 'Warm' 
		WHEN 2 THEN 'Hot' 
	END as 'FS Active Storage Type', COUNT(1) as 'Cnt' 
FROM FileSystemStorageSettings WHERE IsActive=1
GROUP BY StorageTypeID
GO 
SELECT CASE COUNT(1) 
	WHEN 0 THEN 'false'
	ELSE 'true'
	END AS 'WebCat Installed'
FROM ServicesWebsiteCategories
SELECT	SrvVersion,
		--OperatingSystemType,
		OSType,
		AgentType,
		OperatingSystemVersionID
		INTO #OIT_Agents
FROM [ObserveIT].[dbo].[ServerInvatory] 
WHERE SrvVersion != 'Uninstalled'
-- Fix the Agent OS to Mac if needed
UPDATE #OIT_Agents SET OSType = 5
WHERE OperatingSystemVersionID IN (select OperatingSystemVersionID from OperatingSystemVersion where VersionName like 'MAC-OSX%')
AND	OSType = 1
SELECT	distinct(SrvVersion) AS 'Endpoints',
		CASE OSType WHEN 1 THEN 'Windows' WHEN '2' THEN 'Unix' WHEN '5' THEN 'Mac' ELSE 'Other' END AS "OS",
		CASE AgentType 
			WHEN 0 THEN 'Unknown' 
			WHEN 1 THEN 'Workstation' 
			WHEN 2 THEN 'Server' 
			WHEN 3 THEN 'TerminalServer' 
			WHEN 4 THEN 'Site'
			WHEN 5 THEN 'Unix' 
			WHEN 6 THEN 'ActiveX'
			WHEN 7 THEN 'Mac'
		END as 'Type',
 		COUNT(1) AS 'Cnt' 
FROM #OIT_Agents 
GROUP BY SrvVersion,OSType,AgentType
/*
-- uninstalled agents
SELECT	SrvVersion,
		OperatingSystemType,
		AgentType,
		OperatingSystemVersionID
		INTO #OIT_UnInstAgents
FROM [ObserveIT].[dbo].[ServerInvatory] 
WHERE SrvVersion = 'Uninstalled'
SELECT	distinct(SrvVersion) AS 'Uninstalled Endpoints',
		CASE OperatingSystemType WHEN 1 THEN 'Windows' WHEN '2' THEN 'Unix' WHEN '5' THEN 'Mac' ELSE 'Other' END AS "OS",
		CASE AgentType 
			WHEN 0 THEN 'Unknown' 
			WHEN 1 THEN 'Workstation' 
			WHEN 2 THEN 'Server' 
			WHEN 3 THEN 'TerminalServer' 
			WHEN 4 THEN 'Site'
			WHEN 5 THEN 'Unix' 
			WHEN 6 THEN 'ActiveX'
			WHEN 7 THEN 'Mac'
		END as 'Type',
 		COUNT(1) AS 'Cnt' 
FROM #OIT_UnInstAgents
GROUP BY SrvVersion,OperatingSystemType,AgentType
SELECT		sc.PropertyValue AS 'ApplicationServerURL',COUNT(1) AS 'EndpointsConnected'
FROM		ServerConfiguration sc 
WHERE		sc.PropertyId = 4
AND			sc.PropertyValue != ''
GROUP BY	sc.PropertyValue
SELECT distinct(Version) AS 'Non-Active Application-Servers',COUNT(1) AS 'Cnt' 
FROM [ObserveIT].[dbo].[ApplicationServers] 
WHERE UpdatedDate <= GETDATE()-3
GROUP BY Version
GO 
*/